0.9.9 API documentation: vector_float4_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
vector_float4_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef vec< 4, float, highp > | highp_vec4
| 4 components vector of high single-qualifier floating-point numbers. More...
typedef vec< 4, float, lowp > | lowp_vec4
| 4 components vector of low single-qualifier floating-point numbers. More...
typedef vec< 4, float, mediump > | mediump_vec4
| 4 components vector of medium single-qualifier floating-point numbers. More...

## Detailed Description

Core features

Definition in file vector_float4_precision.hpp.